/* @file dhcp6_nic.c
 *
 * Network Interface Configurator for the DHCPv6 IPv6 DHCP client library.
 *
 * @author Jason Vas Dias<jvdias@redhat.com>
 *
 */
/*
 *  Copyright(C) Jason Vas Dias <jvdias@redhat.com> Red Hat Inc. May 2006
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation at 
 *           http://www.fsf.org/licensing/licenses/gpl.txt
 *  and included in this software distribution as the "LICENSE" file.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */
#include <libdhcp.h>
#include <dhcp6_lease.h>
#include <nic.h>
#include <stdarg.h>

/**
 * @addtogroup  DHCPv6
 * @{
 */
typedef
struct dhcp6_nic_s
{
    NLH_t          nh;
    NIC_t          nic;
    IPaddr_list_t  address_list;
    IProute_list_t route_list;
    IPaddr_list_t  dns_list;
    char          *search_list;
    char          *host_name;
    DHCPv6_lease  *lease;
    char          *name;
} DHCPv6_nic;

extern
DHCPv6_nic *do_dhcpv6( LIBDHCP_Control *, NLH_t nh, char *if_name );

extern
DHCPv6_nic *dhcp6_nic_from_lease( LIBDHCP_Control *ctl, NLH_t nh, DHCPv6_lease *lease, NIC_t nic);

extern
int dhcp6_process_lease( LIBDHCP_Control *ctl, DHCPv6_nic *nic );

extern
NIC_Res_t dhcpv6_nic( DHCPv6_nic* );

extern
int dhcp6_nic_callback
(   LIBDHCP_Control *control,
    DHCP_State state, 
    void *arg
);

void dhcpv6_nic_free( DHCPv6_nic* );

/**@}*/
